bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO
===============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianToGaussianGammaISO

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianToGaussianGammaISO.__init__
      ~GaussianToGaussianGammaISO.add_plate_axis
      ~GaussianToGaussianGammaISO.broadcasting_multiplier
      ~GaussianToGaussianGammaISO.delete
      ~GaussianToGaussianGammaISO.get_mask
      ~GaussianToGaussianGammaISO.get_moments
      ~GaussianToGaussianGammaISO.get_shape
      ~GaussianToGaussianGammaISO.has_plotter
      ~GaussianToGaussianGammaISO.lower_bound_contribution
      ~GaussianToGaussianGammaISO.move_plates
      ~GaussianToGaussianGammaISO.plot
      ~GaussianToGaussianGammaISO.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianToGaussianGammaISO.plates
      ~GaussianToGaussianGammaISO.plates_multiplier
   
   